@@ -129,7 +129,7 @@ namespace
   class test_connection : public epee::net_utils::i_service_endpoint
   {
   public:
-    test_connection(boost::asio::io_service& io_service, test_levin_protocol_handler_config& protocol_config)
+    test_connection(boost::asio::io_context& io_service, test_levin_protocol_handler_config& protocol_config)
       : m_io_service(io_service)
       , m_protocol_handler(this, protocol_config, m_context)
       , m_send_return(true)
@@ -155,7 +155,7 @@ namespace
     virtual bool send_done()                          { /*std::cout << "test_connection::send_done()" << std::endl; */return true; }
     virtual bool call_run_once_service_io()           { std::cout << "test_connection::call_run_once_service_io()" << std::endl; return true; }
     virtual bool request_callback()                   { std::cout << "test_connection::request_callback()" << std::endl; return true; }
-    virtual boost::asio::io_service& get_io_service() { std::cout << "test_connection::get_io_service()" << std::endl; return m_io_service; }
+    virtual boost::asio::io_context& get_io_context() { std::cout << "test_connection::get_io_context()" << std::endl; return m_io_service; }
     virtual bool add_ref()                            { std::cout << "test_connection::add_ref()" << std::endl; return true; }
     virtual bool release()                            { std::cout << "test_connection::release()" << std::endl; return true; }
 
@@ -171,7 +171,7 @@ namespace
     test_levin_protocol_handler m_protocol_handler;
 
   private:
-    boost::asio::io_service& m_io_service;
+    boost::asio::io_context& m_io_service;
     test_levin_connection_context m_context;
 
     unit_test::call_counter m_send_counter;
@@ -216,7 +216,7 @@ namespace
     }
 
   protected:
-    boost::asio::io_service m_io_service;
+    boost::asio::io_context m_io_service;
     test_levin_protocol_handler_config m_handler_config;
     test_levin_commands_handler *m_pcommands_handler, &m_commands_handler;
   };
